# Generated by Django 5.0.9 on 2025-01-02 16:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("atoum", "0002_shopping_shoppingitem_shopping_products_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="shopping",
            name="title",
            field=models.CharField(
                blank=True,
                default="",
                max_length=100,
                unique=True,
                verbose_name="title",
            ),
        ),
    ]
