# Generated by Django 5.0.9 on 2025-01-06 16:02

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("atoum", "0003_alter_shopping_title"),
    ]

    operations = [
        migrations.AddField(
            model_name="shopping",
            name="done",
            field=models.BooleanField(blank=True, default=False, verbose_name="done"),
        ),
    ]
