# Generated by Django 5.0.9 on 2025-01-18 01:15

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("atoum", "0005_alter_shopping_title"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="shopping",
            name="products",
        ),
    ]
