{% extends "atoum/base.html" %}
{% load i18n %}
{% block header-title %}{% translate "Todo" %} - {{ block.super }}{% endblock header-title %}

{% block title-content %}{% spaceless %}
    <h1>{% translate "Todo" %}</h1>
{% endspaceless %}{% endblock title-content %}

{% block app_content %}{% spaceless %}
<div>
    <p>Nothing here.</p>
</div>
{% endspaceless %}{% endblock app_content %}
