# Generated by Django 5.0.9 on 2025-01-18 01:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("atoum", "0006_remove_shopping_products"),
    ]

    operations = [
        migrations.AddField(
            model_name="shopping",
            name="products",
            field=models.ManyToManyField(
                blank=True,
                related_name="shoppings",
                through="atoum.ShoppingItem",
                to="atoum.product",
                verbose_name="items",
            ),
        ),
    ]
